@@ -37,17 +37,77 @@ from Nagstamon import Actions
 from Nagstamon.Objects import *
 from Nagstamon.Server.Generic import GenericServer
 
+
 class MultisiteError(Exception):
     def __init__(self, terminate, result):
         self.terminate = terminate
         self.result    = result
+        
+        
+class LastCheckColumnMultisite(Column):
+    """
+    because Check_MK has a pretty different date format (much better readable) it has to
+    be treaten differently
+    
+    This is a custom version of LastCheckColumn to be used in list COLUMNS in class Multisite
+    """
+    
+    ATTR_NAME = 'last_check'
+    
+    @classmethod
+    def sort_function(cls, model, iter1, iter2, column):
+        """ Overrides default sorting behaviour """       
+        data1, data2 = [model.get_value(x, column) for x in (iter1, iter2)]
+        try:            
+            first = Actions.MachineSortableDateMultisite(data1)
+            second = Actions.MachineSortableDateMultisite(data2)
+        except ValueError, err:
+            print err
+            return cmp(first, second)
+        return first - second
+    
+    
+class DurationColumnMultisite(CustomSortingColumn):
+    ATTR_NAME = 'duration'
+    
+    @classmethod
+    def sort_function(cls, model, iter1, iter2, column):
+        """ Overrides default sorting behaviour """       
+        data1, data2 = [model.get_value(x, column) for x in (iter1, iter2)]
+        try:            
+            first = Actions.MachineSortableDateMultisite(data1)
+            second = Actions.MachineSortableDateMultisite(data2)
+        except ValueError, err:
+            print err
+            return cmp(first, second)
+        return first - second
+    
 
 class MultisiteServer(GenericServer):
     """
        special treatment for Check_MK Multisite JSON API
     """
     TYPE = 'Check_MK Multisite'
-
+    
+    # URLs for browser shortlinks/buttons on popup window
+    BROWSER_URLS= { "monitor": "$MONITOR$",\
+                    "hosts": "$MONITOR$/index.py?start_url=view.py?view_name=nagstamon_hosts",\
+                    "services": "$MONITOR$/index.py?start_url=view.py?view_name=nagstamon_svc",\
+                    "history": '$MONITOR$/index.py?start_url=view.py?view_name=events'}    
+    
+    # A Monitor CGI URL is not necessary so hide it in settings
+    DISABLED_CONTROLS = ["label_monitor_cgi_url", "input_entry_monitor_cgi_url"]
+    
+    COLUMNS = [
+        HostColumn,
+        ServiceColumn,
+        StatusColumn,
+        LastCheckColumnMultisite,
+        DurationColumnMultisite,
+        AttemptColumn,
+        StatusInformationColumn
+    ]
+    
     def __init__(self, **kwds):
         GenericServer.__init__(self, **kwds)
         
@@ -56,34 +116,36 @@ class MultisiteServer(GenericServer):
         self.statemap = {}
         
         # Entries for monitor default actions in context menu
-        self.MENU_ACTIONS = ["Recheck", "Acknowledge", "Downtime"]
+        self.MENU_ACTIONS = ["Monitor", "Recheck", "Acknowledge", "Downtime"]
         
 
     def init_HTTP(self):
         # Fix eventually missing tailing "/" in url
-        if self.nagios_url[-1] != '/':
-            self.nagios_url += '/'
+        if self.monitor_url[-1] != '/':
+            self.monitor_url += '/'
         
         # Prepare all urls needed by nagstamon if not yet done
         if len(self.urls) == len(self.statemap):
             self.urls = {
-              'api_services':    self.nagios_url + "view.py?view_name=nagstamon_svc&output_format=python",
-              'human_services':  self.nagios_url + "index.py?%s" % \
+              'api_services':    self.monitor_url + "view.py?view_name=nagstamon_svc&output_format=python",
+              'human_services':  self.monitor_url + "index.py?%s" % \
                                                    urllib.urlencode({'start_url': 'view.py?view_name=nagstamon_svc'}),
-              'human_service':   self.nagios_url + "index.py?%s" %
+              'human_service':   self.monitor_url + "index.py?%s" %
                                                    urllib.urlencode({'start_url': 'view.py?view_name=service'}),
     
-              'api_hosts':       self.nagios_url + "view.py?view_name=nagstamon_hosts&output_format=python",
-              'human_hosts':     self.nagios_url + "index.py?%s" %
+              'api_hosts':       self.monitor_url + "view.py?view_name=nagstamon_hosts&output_format=python",
+              'human_hosts':     self.monitor_url + "index.py?%s" %
                                                    urllib.urlencode({'start_url': 'view.py?view_name=nagstamon_hosts'}),
-              'human_host':      self.nagios_url + "index.py?%s" %
+              'human_host':      self.monitor_url + "index.py?%s" %
                                                    urllib.urlencode({'start_url': 'view.py?view_name=hoststatus'}),
     
-              'api_reschedule':  self.nagios_url + 'nagios_action.py?action=reschedule',
-              'api_host_act':    self.nagios_url + 'view.py?_transid=-1&_do_actions=yes&_do_confirm=Yes!&output_format=python&view_name=hoststatus',
-              'api_service_act': self.nagios_url + 'view.py?_transid=-1&_do_actions=yes&_do_confirm=Yes!&output_format=python&view_name=service',
+              'api_reschedule':  self.monitor_url + 'nagios_action.py?action=reschedule',
+              'api_host_act':    self.monitor_url + 'view.py?_transid=-1&_do_actions=yes&_do_confirm=Yes!&output_format=python&view_name=hoststatus',
+              'api_service_act': self.monitor_url + 'view.py?_transid=-1&_do_actions=yes&_do_confirm=Yes!&output_format=python&view_name=service',
+              'human_events':    self.monitor_url + "index.py?%s" %
+                                                   urllib.urlencode({'start_url': 'view.py?view_name=events'}),
             }
-    
+
             self.statemap = {
                 'UNREACH': 'UNREACHABLE',
                 'CRIT':    'CRITICAL',
@@ -208,13 +270,13 @@ class MultisiteServer(GenericServer):
             for row in response[1:]:
                 service = dict(zip(response[0], row))
                 n = {
-                    'host':               service['host'],
-                    'service':            service['service_description'],
+                    'host':               service['host'].encode("utf-8"),
+                    'service':            service['service_description'].encode("utf-8"),
                     'status':             self.statemap.get(service['service_state'], service['service_state']),
                     'last_check':         service['svc_check_age'],
                     'duration':           service['svc_state_age'],
                     'attempt':            service['svc_attempt'],
-                    'status_information': service['svc_plugin_output'],
+                    'status_information': service['svc_plugin_output'].encode("utf-8"),
                     # Check_MK passive services can be re-scheduled by using the Check_MK service
                     'passiveonly':        service['svc_is_active'] == 'no' and not service['svc_check_command'].startswith('check_mk'),
                     'notifications':      service['svc_notifications_enabled'] == 'yes',
@@ -223,7 +285,7 @@ class MultisiteServer(GenericServer):
                     'address':            service['host_address'],
                     'command':            service['svc_check_command'],
                 }
-
+                
                 # add dictionary full of information about this service item to nagitems - only if service
                 nagitems["services"].append(n)
                 # after collection data in nagitems create objects of its informations
@@ -271,19 +333,7 @@ class MultisiteServer(GenericServer):
 
         return ret
 
-
-    def _open_browser(self, url):
-        webbrowser.open(url)
-
-        if str(self.conf.debug_mode) == "True":
-            self.Debug(server=self.get_name(), debug="Open web page " + url)
-
-    def open_services(self):
-        self._open_browser(self.urls['human_services'])
-
-    def open_hosts(self):
-        self._open_browser(self.urls['human_hosts'])
-
+            
     def open_tree_view(self, host, service=""):
         """
         open monitor from treeview context menu
@@ -306,7 +356,7 @@ class MultisiteServer(GenericServer):
         """
         
         # the fasted method is taking hostname as used in monitor
-        if str(self.conf.connect_by_host) == "True":
+        if str(self.conf.connect_by_host) == "True" or host == "":
             return Result(result=host)
 
         ip = ""
@@ -401,3 +451,8 @@ class MultisiteServer(GenericServer):
         # acknowledge all services on a host when told to do so
         for s in all_services:
             self._action(self.hosts[host].site, host, s, p)
+            
+
+
+
+        
\ No newline at end of file
